@@ -33,6 +33,13 @@ class Validator(object):
     def has_default(self):
         pass
 
+    @abstractmethod
+    def is_optional(self):
+        """
+        Indicates if the instance must be defined.
+        """
+        pass
+
     @abstractmethod
     def validate(self, obj):
         pass
@@ -76,6 +83,9 @@ class ReferenceValidator(Validator):
     def default(self):
         return self.validator.default
 
+    def is_optional(self):
+        return self.validator.is_optional()
+
     def validate(self, obj):
         """
         Validate object against validator
